#[non_exhaustive]pub enum AccessError {
PermissionRevoked,
Io {
source: Error,
},
InvalidDescriptor,
Platform {
message: String,
},
}Expand description
Errors that can occur when opening or accessing a previously granted file.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PermissionRevoked
The permission grant for this file has been revoked by the user or OS.
Io
An I/O error occurred while reading from or writing to the file.
InvalidDescriptor
The file descriptor or handle returned by the platform was invalid.
Platform
The platform returned an error when attempting to open the file.