#[non_exhaustive]pub enum PickerError {
Platform {
message: String,
},
Unsupported {
operation: String,
},
Internal {
message: String,
},
}Expand description
Errors that can occur when presenting a file-picker dialog.
Note that the user cancelling the dialog is not an error — it is
represented as Ok(None) on the single-file methods and Ok(vec![]) on
multi-file methods.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Platform
The platform returned an error from the native file-picker API.
Unsupported
The current platform does not support the requested operation.
Internal
An internal synchronisation error occurred (e.g. a poisoned mutex).