#[non_exhaustive]pub enum PermissionStatus {
Valid,
Revoked,
Unknown,
}Expand description
Status of the permission grant associated with a FileAccessToken.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Valid
The token’s permission is still valid and the file can be opened.
Revoked
The permission has been revoked by the user or the operating system.
Unknown
The permission status cannot be determined on this platform.